﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace CSharp_To_HTML
{
    public partial class MainForm : Form
    {
        private CSharpFormat _format = new CSharpFormat();

        public MainForm()
        {
            InitializeComponent();
            txtCsharp.DelayedEventInterval = 500;
            _format.EmbedStyleSheet = true;
        }

        private void UpdateHTML()
        {
            txtHTML.Text = _format.FormatCode(txtCsharp.Text);
            browserPreview.DocumentText = txtHTML.Text;
        }

        private void txtCsharp_TextChangedDelayed(object sender, EventArgs e)
        {
            UpdateHTML();
        }

        private void btnDownloadStyle_Click(object sender, EventArgs e)
        {
            using (SaveFileDialog dlgSaveFile = new SaveFileDialog())
            {
                dlgSaveFile.Filter = "Style Sheet|*.css";
                dlgSaveFile.FileName = "CSharpStyleSheet.css";

                if (dlgSaveFile.ShowDialog() == DialogResult.OK)
                {
                    try
                    {
                        string content = Encoding.ASCII.GetString(Properties.Resources.csharp);
                        File.WriteAllText(dlgSaveFile.FileName, content);

                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(ex.Message, Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                }
            }
        }

        /// <summary>
        /// Allow use to select all text with the textboxes
        /// </summary>
        protected override void OnKeyDown(KeyEventArgs e)
        {
            base.OnKeyDown(e);

            if (e.KeyCode == Keys.A && e.Control)
            {
                if (txtCsharp.Focused)
                {
                    txtCsharp.SelectAll();
                }
                else if (txtHTML.Focused)
                {
                    txtHTML.SelectAll();
                }
            }
        }

        private void chkEmbedSheet_CheckedChanged(object sender, EventArgs e)
        {
            _format.EmbedStyleSheet = chkEmbedSheet.Checked;
            UpdateHTML();
        }

        private void chkAlternateLines_CheckedChanged(object sender, EventArgs e)
        {
            _format.Alternate = chkAlternateLines.Checked;
            UpdateHTML();
        }

        private void chkLineNumbers_CheckedChanged(object sender, EventArgs e)
        {
            _format.LineNumbers = chkLineNumbers.Checked;
            UpdateHTML();

        }

        private void btnCopyToClip_Click(object sender, EventArgs e)
        {
            Clipboard.SetText(txtHTML.Text);
        }

        private void linkWebApp_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start(linkWebApp.Text);
        }
    }
}
